@@ -4,12 +4,14 @@ from .ddt_pos import DdtPosBenchmark  # noqa
 from .ddt_dep import DdtDepBenchmark  # noqa
 from .angry_tweets import AngryTweetsBenchmark  # noqa
 from .twitter_sent import TwitterSentBenchmark  # noqa
-from .twitter_subj import TwitterSubjBenchmark  # noqa
-from .europarl_subj import EuroparlSubjBenchmark  # noqa
-from .europarl_sent import EuroparlSentBenchmark  # noqa
+from .europarl import EuroparlBenchmark  # noqa
 from .lcc import LccBenchmark  # noqa
 from .dkhate import DkHateBenchmark  # noqa
 from .norec import NoReCBenchmark  # noqa
 from .nordial import NorDialBenchmark  # noqa
 from .norne_nb import NorneNBBenchmark  # noqa
 from .norne_nn import NorneNNBenchmark  # noqa
+from .ndt_nb_pos import NdtNBPosBenchmark  # noqa
+from .ndt_nn_pos import NdtNNPosBenchmark  # noqa
+from .ndt_nb_dep import NdtNBDepBenchmark  # noqa
+from .ndt_nn_dep import NdtNNDepBenchmark  # noqa
