@@ -201,6 +201,98 @@ def load_dane_no_misc() -> Tuple[dict, dict, dict, dict]:
     return X_train, X_test, y_train, y_test
 
 
+def load_ndt_nb_pos() -> Tuple[dict, dict, dict, dict]:
+    '''Load the Bokmål POS part of the NDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/norne_nb/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             'pos_tags')
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           'pos_tags')
+    return X_train, X_test, y_train, y_test
+
+
+def load_ndt_nn_pos() -> Tuple[dict, dict, dict, dict]:
+    '''Load the Nynorsk POS part of the NDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/norne_nn/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             'pos_tags')
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           'pos_tags')
+    return X_train, X_test, y_train, y_test
+
+
+def load_ndt_nb_dep() -> Tuple[dict, dict, dict, dict]:
+    '''Load the Bokmål POS part of the NDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/norne_nb/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             ['heads', 'deps'])
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           ['heads', 'deps'])
+    return X_train, X_test, y_train, y_test
+
+
+def load_ndt_nn_dep() -> Tuple[dict, dict, dict, dict]:
+    '''Load the Nynorsk POS part of the NDT dataset.
+
+    Returns:
+        tuple:
+            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
+            `X_train` and `X_test` corresponds to the feature matrices for the
+            training and test split, respectively, and `y_train` and `y_test`
+            contains the target vectors.
+    '''
+    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
+                'main/datasets/norne_nn/')
+    train_url = base_url + 'train.jsonl'
+    test_url = base_url + 'test.jsonl'
+    X_train, y_train = _get_dataset_from_url(train_url,
+                                             ['doc', 'tokens'],
+                                             ['heads', 'deps'])
+    X_test, y_test = _get_dataset_from_url(test_url,
+                                           ['doc', 'tokens'],
+                                           ['heads', 'deps'])
+    return X_train, X_test, y_train, y_test
+
+
 def load_ddt_pos() -> Tuple[dict, dict, dict, dict]:
     '''Load the POS part of the DDT dataset.
 
@@ -266,10 +358,8 @@ def load_dkhate() -> Tuple[dict, dict, dict, dict]:
     return X_train, X_test, y_train, y_test
 
 
-def load_twitter_subj() -> Tuple[dict, dict, dict, dict]:
-    '''Load the TwitterSubj dataset.
-
-    This dataset is the subjectivity part of the TwitterSent dataset.
+def load_europarl() -> Tuple[dict, dict, dict, dict]:
+    '''Load the Europarl dataset.
 
     Returns:
         tuple:
@@ -279,49 +369,7 @@ def load_twitter_subj() -> Tuple[dict, dict, dict, dict]:
             contains the target vectors.
     '''
     base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
-                'main/datasets/twitter_subj/')
-    train_url = base_url + 'train.jsonl'
-    test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url, 'tweet', 'label')
-    X_test, y_test = _get_dataset_from_url(test_url, 'tweet', 'label')
-    return X_train, X_test, y_train, y_test
-
-
-def load_europarl_subj() -> Tuple[dict, dict, dict, dict]:
-    '''Load the EuroparlSubj dataset.
-
-    This dataset is the subjectivity part of the Europarl2 dataset.
-
-    Returns:
-        tuple:
-            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
-            `X_train` and `X_test` corresponds to the feature matrices for the
-            training and test split, respectively, and `y_train` and `y_test`
-            contains the target vectors.
-    '''
-    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
-                'main/datasets/europarl_subj/')
-    train_url = base_url + 'train.jsonl'
-    test_url = base_url + 'test.jsonl'
-    X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
-    X_test, y_test = _get_dataset_from_url(test_url, 'text', 'label')
-    return X_train, X_test, y_train, y_test
-
-
-def load_europarl_sent() -> Tuple[dict, dict, dict, dict]:
-    '''Load the EuroparlSent dataset.
-
-    This dataset is the sentiment part of the Europarl2 dataset.
-
-    Returns:
-        tuple:
-            Four dicts, `X_train`, `X_test`, `y_train` and `y_test`, where
-            `X_train` and `X_test` corresponds to the feature matrices for the
-            training and test split, respectively, and `y_train` and `y_test`
-            contains the target vectors.
-    '''
-    base_url = ('https://raw.githubusercontent.com/saattrupdan/ScandEval/'
-                'main/datasets/europarl_sent/')
+                'main/datasets/europarl/')
     train_url = base_url + 'train.jsonl'
     test_url = base_url + 'test.jsonl'
     X_train, y_train = _get_dataset_from_url(train_url, 'text', 'label')
