@@ -47,15 +47,9 @@ def get_all_datasets() -> list:
         ('twitter-sent', 'TwitterSent',
             locate('scandeval.benchmarks.TwitterSentBenchmark'),
             locate('scandeval.datasets.load_twitter_sent')),
-        ('twitter-subj', 'TwitterSubj',
-            locate('scandeval.benchmarks.TwitterSubjBenchmark'),
-            locate('scandeval.datasets.load_twitter_subj')),
-        ('europarl-sent', 'EuroparlSent',
-            locate('scandeval.benchmarks.EuroparlSentBenchmark'),
-            locate('scandeval.datasets.load_europarl_sent')),
-        ('europarl-subj', 'EuroparlSubj',
-            locate('scandeval.benchmarks.EuroparlSubjBenchmark'),
-            locate('scandeval.datasets.load_europarl_subj')),
+        ('europarl', 'Europarl',
+            locate('scandeval.benchmarks.EuroparlBenchmark'),
+            locate('scandeval.datasets.load_europarl')),
         ('dkhate', 'DKHate',
             locate('scandeval.benchmarks.DkHateBenchmark'),
             locate('scandeval.datasets.load_dkhate')),
@@ -73,7 +67,19 @@ def get_all_datasets() -> list:
             locate('scandeval.datasets.load_norne_nb')),
         ('norne-nn', 'the Nynorsk part of NorNE',
             locate('scandeval.benchmarks.NorneNNBenchmark'),
-            locate('scandeval.datasets.load_norne_nn'))
+            locate('scandeval.datasets.load_norne_nn')),
+        ('ndt-nb-pos', 'the Bokmål POS part of NDT',
+            locate('scandeval.benchmarks.NdtNBPosBenchmark'),
+            locate('scandeval.datasets.load_ndt_nb_pos')),
+        ('ndt-nn-pos', 'the Nynorsk POS part of NDT',
+            locate('scandeval.benchmarks.NdtNNPosBenchmark'),
+            locate('scandeval.datasets.load_ndt_nn_pos')),
+        ('ndt-nb-dep', 'the Bokmål DEP part of NDT',
+            locate('scandeval.benchmarks.NdtNBDepBenchmark'),
+            locate('scandeval.datasets.load_ndt_nb_dep')),
+        ('ndt-nn-dep', 'the Nynorsk DEP part of NDT',
+            locate('scandeval.benchmarks.NdtNNDepBenchmark'),
+            locate('scandeval.datasets.load_ndt_nn_dep')),
     ]
 
 
